package envoy.client.ui;

import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.JButton;

import envoy.client.Settings;
import envoy.client.SettingsItem;

/**
 * This component can be used to toggle between two options. This will change
 * the state of a {@code boolean} {@link SettingsItem}.<br>
 * <br>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>PrimaryToggleSwitch.java</strong><br>
 * Created: <strong>21 Dec 2019</strong><br>
 * 
 * @author Maximilian K&auml;fer
 * @author Kai S. K. Engelbart
 * @since Envoy v0.3-alpha
 */
public class PrimaryToggleSwitch extends JButton {

	private boolean state;

	private static final long serialVersionUID = -721155303106833184L;

	/**
	 * Initializes a {@link PrimaryToggleSwitch}.
	 * 
	 * @param settingsItem the {@link SettingsItem} that is controlled by this
	 *                     {@link PrimaryToggleSwitch}
	 * @since Envoy v0.3-alpha
	 */
	public PrimaryToggleSwitch(SettingsItem<Boolean> settingsItem) {
		setPreferredSize(new Dimension(50, 25));
		setMinimumSize(new Dimension(50, 25));
		setMaximumSize(new Dimension(50, 25));

		setBorderPainted(false);
		setFocusPainted(false);
		setContentAreaFilled(false);

		state = settingsItem.get();
		addActionListener((evt) -> { state = !state; settingsItem.set(state); revalidate(); repaint(); });
	}

	@Override
	public void paintComponent(Graphics g) {
		g.setColor(state ? Color.GREEN : Color.LIGHT_GRAY);
		g.fillRoundRect(0, 0, getWidth(), getHeight(), 25, 25);

		g.setColor(Settings.getInstance().getThemes().get(Settings.getInstance().getCurrentTheme()).getInteractableBackgroundColor());
		g.fillRoundRect(state ? 25 : 0, 0, 25, 25, 25, 25);
	}
}