package envoy.client.ui.settings;

import java.awt.event.ActionListener;

import javax.swing.JPanel;

/**
 * Serves as an interface between {@link SettingsScreen} and different
 * {@link JPanel}s with actual settings that are defined as sub classes of this
 * class.<br>
 * <br>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>SettingsPanel.java</strong><br>
 * Created: <strong>20 Dec 2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy v0.2-alpha
 */
public abstract class SettingsPanel extends JPanel {

	protected final SettingsScreen parent;

	private static final long serialVersionUID = -3069212622468626050L;

	/**
	 * Initializes a {@link SettingsPanel}.
	 * 
	 * @param parent the {@link SettingsScreen} as a part of which this
	 *               {@link SettingsPanel} is displayed
	 */
	public SettingsPanel(SettingsScreen parent) { this.parent = parent; }

	/**
	 * @return an {@link ActionListener} that should be invoked when the OK button
	 *         is pressed in the {@link SettingsScreen}
	 * @since Envoy v0.2-alpha
	 */
	public abstract ActionListener getOkButtonAction();
}
