package envoy.client.util;

import java.io.*;

import envoy.exception.EnvoyException;

/**
 * Project: <strong>envoy-clientChess</strong><br>
 * File: <strong>SerializationUtils.javaEvent.java</strong><br>
 * Created: <strong>23.12.2019</strong><br>
 * 
 * @author Kai S. K. Engelbart
 * @since Envoy v0.3-alpha
 */
public class SerializationUtils {

	private SerializationUtils() {}

	/**
	 * Deserializes an arbitrary {@link Serializable} object from a file.
	 * 
	 * @param <T>             the type of the object to deserialize
	 * @param file            the file deserialize from
	 * @param serializedClass the class of the object to deserialize
	 * @return the deserialized object
	 * @throws EnvoyException if an error occurred during deserialization
	 * @since Envoy v0.3-alpha
	 */
	public static <T extends Serializable> T read(File file, Class<T> serializedClass) throws EnvoyException {
		if (file == null) throw new NullPointerException("File is null");
		try (ObjectInputStream in = new ObjectInputStream(new FileInputStream(file))) {
			return serializedClass.cast(in.readObject());
		} catch (ClassNotFoundException | IOException e) {
			throw new EnvoyException("Could not load serialized object", e);
		}
	}

	/**
	 * Serializes an arbitrary object to a file.
	 * 
	 * @param file the file to serialize to
	 * @param obj  the object to serialize
	 * @throws IOException if an error occurred during serialization
	 * @since Envoy v0.3-alpha
	 */
	public static void write(File file, Object obj) throws IOException {
		if (file == null) throw new NullPointerException("File is null");
		if (obj == null) throw new NullPointerException("Object to serialize is null");
		if (!file.exists()) {
			file.getParentFile().mkdirs();
			file.createNewFile();
		}
		try (ObjectOutputStream out = new ObjectOutputStream(new FileOutputStream(file))) {
			out.writeObject(obj);
		}
	}
}